/**
 * Tests for unserve-function
 */
;(function () {
  /* global describe, it, before */
  'use strict'

  /** imports */
  var expect = require('chai').expect
  var unserve = require('../unserve-function')
  var express = require('express')

  var TEST_PORT = 12345

  /**
   * Tests
   */
  describe('unserve-function', function () {
    var server

    beforeEach(function (done) {
      var app = express()

      app.get('/api', function (request, response) {
        var options = request.query
        Object.keys(options).forEach(function (key) {
          if (
            typeof key === 'string' &&
            /^([0-9]+\.?[0-9]*)|([0-9]*\.?[0-9]+)$/.test(options[key])
          ) {
            options[key] = Number(options[key])
          }
        })
        response.json(options)
      })

      server = app.listen(TEST_PORT, function () {
        done()
      })
    })

    afterEach(function (done) {
      server.close()
      done()
    })

    it('should unserve a REST API', function (done) {
      var url = 'http://localhost:' + TEST_PORT + '/api'

      var unserved = unserve(url)

      var options = {
        a: 'stuff and ',
        b: 3.1,
        c: ' dogs'
      }

      unserved(options, function (error, result) {
        expect(error).to.not.be.ok

        expect(result).to.deep.equal(options)
        done()
      })
    })
  })
})()
